@@ -4,24 +4,20 @@
 //!
 //! This crate contains some additions to [nom](https://github.com/Geal/nom).
 //!
-//! For example, the `error_if!` macro allows to test a condition and return an error from the parser if the condition
-//! fails:
+//! For example, the [`combinator::cond_else`] function allows to apply the first parser if the
+//! condition is true, and the second if the condition is false:
 //!
 //! ```rust
-//! # extern crate rusticata_macros;
-//! # extern crate nom;
-//! # use nom::{do_parse, take, IResult};
-//! # use nom::error::ErrorKind;
-//! # use nom::number::streaming::be_u8;
-//! use rusticata_macros::error_if;
+//! # use nom::IResult;
+//! # use nom::combinator::map;
+//! # use nom::number::streaming::*;
+//! use rusticata_macros::combinator::cond_else;
 //! # fn parser(s:&[u8]) {
-//! let r : IResult<&[u8],()> = do_parse!(
-//!     s,
-//!     l: be_u8 >>
-//!     error_if!(l < 4, ErrorKind::Verify) >>
-//!     data: take!(l - 4) >>
-//!     (())
-//!     );
+//! let r: IResult<_, _, ()> = cond_else(
+//!         || s.len() > 1,
+//!         be_u16,
+//!         map(be_u8, u16::from)
+//!     )(s);
 //! # }
 //! ```
 //!
@@ -35,13 +31,14 @@
     unused_qualifications
 )]
 
-#[macro_use]
-extern crate nom;
-
 pub mod combinator;
-
+pub mod debug;
 pub use macros::*;
 #[macro_use]
 pub mod macros;
 
-pub mod debug;
+mod traits;
+pub use traits::*;
+
+// re-exports
+pub use nom;
